@@ -1,6 +1,6 @@
 cd .. && \
 cargo build --release && \
 cd ./c_header_and_example && \
-cp ../target/release/libstaticvec.dll.a ./libstaticvec.dll.a && \
+cp ../target/release/libstaticvec.dll.lib ./libstaticvec.dll.lib && \
 cp ../target/release/libstaticvec.dll ./libstaticvec.dll && \
-cc ./example.c -o ./example.exe -I. -L. -lstaticvec
+cc -O2 ./example.cpp -o ./example.exe -I. -L. -lstaticvec
