@@ -1,6 +1,8 @@
 #include <cstdio>
 #include <libstaticvec.h>
 
+// I'm aware there's a weird mix of C and C++ going on here...
+
 int main() {
   CStaticVec v = staticvec_new();
   staticvec_push(&v, "A");
@@ -52,5 +54,18 @@ int main() {
   printf("%zu\n", (size_t)staticvec_remove_item(&v, (VoidPtr)1).value);
 
   staticvec_clear(&v);
+
+  const VoidPtr values[VECTOR_CAPACITY] = {
+      "A", "B", "C", "D", "A", "B", "C", "D",
+      "A", "B", "C", "D", "A", "B", "C", "D"};
+
+  CStaticVec v2 = staticvec_new_from_const_array(values);
+
+  for (size_t i = 0; i < staticvec_len(&v2); ++i) {
+    printf("%s\n", (const char *)staticvec_get(&v2, i));
+  }
+
+  staticvec_clear(&v2);
+
   return 0;
 }
