@@ -1,5 +1,7 @@
 #![allow(incomplete_features)]
+#![feature(const_extern_fn)]
 #![feature(const_generics)]
+#![feature(const_raw_ptr_deref)]
 
 use staticvec::StaticVec;
 
@@ -36,7 +38,7 @@ pub struct COption {
 }
 
 #[no_mangle]
-pub unsafe extern "C" fn staticvec_capacity(vec: *const CStaticVec) -> usize {
+pub const unsafe extern "C" fn staticvec_capacity(vec: *const CStaticVec) -> usize {
   (*vec).capacity()
 }
 
@@ -61,15 +63,20 @@ pub unsafe extern "C" fn staticvec_insert(vec: *mut CStaticVec, index: usize, it
 }
 
 #[no_mangle]
-pub unsafe extern "C" fn staticvec_len(vec: *const CStaticVec) -> usize {
+pub const unsafe extern "C" fn staticvec_len(vec: *const CStaticVec) -> usize {
   (*vec).len()
 }
 
 #[no_mangle]
-pub extern "C" fn staticvec_new() -> CStaticVec {
+pub const extern "C" fn staticvec_new() -> CStaticVec {
   StaticVec::new()
 }
 
+#[no_mangle]
+pub const extern "C" fn staticvec_new_from_const_array(values: [VoidPtr; VECTOR_CAPACITY]) -> CStaticVec {
+  StaticVec::new_from_const_array(values)
+}
+
 #[no_mangle]
 pub unsafe extern "C" fn staticvec_pop(vec: *mut CStaticVec) -> COption {
   let res = (*vec).pop();
@@ -92,7 +99,7 @@ pub unsafe extern "C" fn staticvec_push(vec: *mut CStaticVec, item: VoidPtr) {
 }
 
 #[no_mangle]
-pub unsafe extern "C" fn staticvec_remaining_capacity(vec: *const CStaticVec) -> usize {
+pub const unsafe extern "C" fn staticvec_remaining_capacity(vec: *const CStaticVec) -> usize {
   (*vec).remaining_capacity()
 }
 
@@ -123,6 +130,6 @@ pub unsafe extern "C" fn staticvec_set(vec: *mut CStaticVec, index: usize, item:
 }
 
 #[no_mangle]
-pub unsafe extern "C" fn staticvec_size_in_bytes(vec: *const CStaticVec) -> usize {
+pub const unsafe extern "C" fn staticvec_size_in_bytes(vec: *const CStaticVec) -> usize {
   (*vec).size_in_bytes()
 }
